@@ -17,11 +17,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef NDEBUG /* N.B. assert used with active statements so enable always. */
+#undef NDEBUG /* Must undef above assert.h or other that might include it. */
+#endif
+
 #include "sox.h"
 #include <stdio.h>
-#ifdef NDEBUG /* N.B. assert used with active statements so enable always */
-#undef NDEBUG
-#endif
 #include <assert.h>
 
 static sox_format_t * in, * out; /* input and output files */
@@ -110,7 +111,7 @@ int main(int argc, char * argv[])
   assert(argc == 3);
 
   /* All libSoX applications must start by initialising the SoX library */
-  assert(sox_format_init() == SOX_SUCCESS);
+  assert(sox_init() == SOX_SUCCESS);
 
   /* Open the input file (with default parameters) */
   assert(in = sox_open_read(argv[1], NULL, NULL, NULL));
@@ -133,13 +134,13 @@ int main(int argc, char * argv[])
 
   /* Create the `vol' effect, and initialise it with the desired parameters: */
   e = sox_create_effect(sox_find_effect("vol"));
-  assert(e->handler.getopts(e, 1, vol) == SOX_SUCCESS);
+  assert(sox_effect_options(e, 1, vol) == SOX_SUCCESS);
   /* Add the effect to the end of the effects processing chain: */
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
 
   /* Create the `flanger' effect, and initialise it with default parameters: */
   e = sox_create_effect(sox_find_effect("flanger"));
-  assert(e->handler.getopts(e, 0, NULL) == SOX_SUCCESS);
+  assert(sox_effect_options(e, 0, NULL) == SOX_SUCCESS);
   /* Add the effect to the end of the effects processing chain: */
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
 
@@ -150,7 +151,7 @@ int main(int argc, char * argv[])
   assert(sox_add_effect(chain, e, &in->signal, &in->signal) == SOX_SUCCESS);
 
   /* Flow samples through the effects processing chain until EOF is reached */
-  sox_flow_effects(chain, NULL);
+  sox_flow_effects(chain, NULL, NULL);
 
   /* All done; tidy up: */
   sox_delete_effects_chain(chain);
