@@ -24,10 +24,6 @@
 
 #include <FLAC/all.h>
 
-/* Workaround for flac versions < 1.1.2 */
-#define FLAC__metadata_object_vorbiscomment_append_comment(object, entry, copy)\
-  FLAC__metadata_object_vorbiscomment_insert_comment(object, object->data.vorbis_comment.num_comments, entry, copy)
-
 #if !defined(FLAC_API_VERSION_CURRENT)
 #define FLAC_API_VERSION_CURRENT 7
 #define FLAC__StreamDecoder FLAC__FileDecoder
@@ -58,6 +54,8 @@ typedef struct {
 
   FLAC__StreamDecoder * decoder;
   FLAC__bool eof;
+  sox_bool seek_pending;
+  uint64_t seek_offset;
 
   /* Encode buffer: */
   FLAC__int32 * decoded_samples;
@@ -124,6 +122,7 @@ static FLAC__StreamDecoderWriteStatus FLAC__frame_decode_callback(FLAC__StreamDe
     return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
   }
 
+  /* FIXME: We're skating on thin ice here: buffer may be on the stack! */
   p->decoded_wide_samples = buffer;
   p->number_of_wide_samples = frame->header.blocksize;
   p->wide_sample_number = 0;
@@ -194,12 +193,18 @@ static size_t read_samples(sox_format_t * const ft, sox_sample_t * sampleBuffer,
   priv_t * p = (priv_t *)ft->priv;
   size_t actual = 0;
 
+  if (p->seek_pending) {
+    p->seek_pending = sox_false; 
+    p->wide_sample_number = p->number_of_wide_samples = 0;
+    if (!FLAC__stream_decoder_seek_absolute(p->decoder, (FLAC__uint64)(p->seek_offset / ft->signal.channels)))
+      return 0;
+  }
   while (!p->eof && actual < requested) {
     if (p->wide_sample_number >= p->number_of_wide_samples)
       FLAC__stream_decoder_process_single(p->decoder);
     if (p->wide_sample_number >= p->number_of_wide_samples)
       p->eof = sox_true;
-    else {
+    else { /* FIXME: this block should really be inside the decode callback */
       unsigned channel;
 
       for (channel = 0; channel < p->channels; channel++, actual++) {
@@ -436,6 +441,7 @@ static size_t write_samples(sox_format_t * const ft, sox_sample_t const * const
   unsigned i;
 
   for (i = 0; i < len; ++i) {
+    SOX_SAMPLE_LOCALS;
     long pcm = SOX_SAMPLE_TO_SIGNED_32BIT(sampleBuffer[i], ft->clips);
     p->decoded_samples[i] = pcm >> (32 - p->bits_per_sample);
     switch (p->bits_per_sample) {
@@ -480,20 +486,17 @@ static int stop_write(sox_format_t * const ft)
 
 
 
-/*
- * N.B.  Do not call this function with offset=0 when file-pointer
- * is already 0 or a block of decoded FLAC data will be discarded.
- */
 static int seek(sox_format_t * ft, uint64_t offset)
 {
   priv_t * p = (priv_t *)ft->priv;
-  int result = ft->mode == 'r' && FLAC__stream_decoder_seek_absolute(p->decoder, (FLAC__uint64)(offset / ft->signal.channels)) ?  SOX_SUCCESS : SOX_EOF;
-  p->wide_sample_number = p->number_of_wide_samples = 0;
-  return result;
+  p->seek_offset = offset;
+  p->seek_pending = sox_true;
+  return ft->mode == 'r' ? SOX_SUCCESS : SOX_EOF;
 }
 
 
-SOX_FORMAT_HANDLER(flac)
+
+LSX_FORMAT_HANDLER(flac)
 {
   static char const * const names[] = {"flac", NULL};
   static unsigned const encodings[] = {SOX_ENCODING_FLAC, 8, 16, 24, 0, 0};
