@@ -160,23 +160,24 @@ static int parse_subarg(char *s, char **subargv, size_t *subargc) {
       return SOX_SUCCESS;
 }
 
-static int getopts(sox_effect_t * effp, int n, char **argv)
+static int getopts(sox_effect_t * effp, int argc, char **argv)
 {
   char *subargv[6], *cp;
   size_t subargc, i, len;
 
   priv_t * c = (priv_t *) effp->priv;
+  --argc, ++argv;
 
   c->band_buf1 = c->band_buf2 = c->band_buf3 = 0;
   c->band_buf_len = 0;
 
   /* how many bands? */
-  if (! (n&1)) {
-    lsx_fail("mcompand accepts only an odd number of arguments:\n"
+  if (! (argc&1)) {
+    lsx_fail("mcompand accepts only an odd number of arguments:\argc"
             "  mcompand quoted_compand_args [crossover_freq quoted_compand_args [...]");
     return SOX_EOF;
   }
-  c->nBands = (n+1)>>1;
+  c->nBands = (argc+1)>>1;
 
   c->bands = lsx_calloc(c->nBands, sizeof(comp_band_t));
 
@@ -480,7 +481,7 @@ static int kill(sox_effect_t * effp)
   return SOX_SUCCESS;
 }
 
-const sox_effect_handler_t *sox_mcompand_effect_fn(void)
+const sox_effect_handler_t *lsx_mcompand_effect_fn(void)
 {
   static sox_effect_handler_t handler = {
     "mcompand",
@@ -491,7 +492,7 @@ const sox_effect_handler_t *sox_mcompand_effect_fn(void)
     "  attack1,decay1[,attack2,decay2...]\n"
     "                 in-dB1,out-dB1[,in-dB2,out-dB2...]\n"
     "                [ gain [ initial-volume [ delay ] ] ]",
-    SOX_EFF_MCHAN,
+    SOX_EFF_MCHAN | SOX_EFF_GAIN,
     getopts, start, flow, drain, stop, kill, sizeof(priv_t)
   };
 
