@@ -55,11 +55,12 @@ static int parse(sox_effect_t * effp, char * * argv, sox_rate_t rate)
   return SOX_SUCCESS;
 }
 
-static int create(sox_effect_t * effp, int n, char * * argv)
+static int create(sox_effect_t * effp, int argc, char * * argv)
 {
   priv_t * p = (priv_t *)effp->priv;
-  p->pads = lsx_calloc(p->npads = n, sizeof(*p->pads));
-  return parse(effp, argv, 96000.); /* No rate yet; parse with dummy */
+  --argc, ++argv;
+  p->pads = lsx_calloc(p->npads = argc, sizeof(*p->pads));
+  return parse(effp, argv, 1e5); /* No rate yet; parse with dummy */
 }
 
 static int start(sox_effect_t * effp)
@@ -131,10 +132,10 @@ static int kill(sox_effect_t * effp)
   return SOX_SUCCESS;
 }
 
-sox_effect_handler_t const * sox_pad_effect_fn(void)
+sox_effect_handler_t const * lsx_pad_effect_fn(void)
 {
   static sox_effect_handler_t handler = {
-    "pad", "{length[@position]}", SOX_EFF_MCHAN|SOX_EFF_LENGTH,
+    "pad", "{length[@position]}", SOX_EFF_MCHAN|SOX_EFF_LENGTH|SOX_EFF_MODIFY,
     create, start, flow, drain, stop, kill, sizeof(priv_t)
   };
   return &handler;
