@@ -159,6 +159,7 @@ static size_t write_samples(sox_format_t * ft, const sox_sample_t *buf, size_t l
   switch (ft->encoding.bits_per_sample) {
   case 8:
     switch (ft->encoding.encoding) {
+    SOX_SAMPLE_LOCALS;
     case SOX_ENCODING_UNSIGNED:
       while (done < len && lsx_writeb(ft, SOX_SAMPLE_TO_UNSIGNED_8BIT(*buf++, ft->clips)) == SOX_SUCCESS)
         ++done;
@@ -189,13 +190,13 @@ static int seek(sox_format_t UNUSED * ft, uint64_t UNUSED offset)
   return SOX_SUCCESS;
 }
 
-SOX_FORMAT_HANDLER(skel)
+LSX_FORMAT_HANDLER(skel)
 {
   /* Format file suffixes */
   static const char *names[] = {"skel",NULL };
 
   /* Encoding types and sizes that this handler can write */
-  static unsigned encodings[] = {
+  static const unsigned encodings[] = {
     SOX_ENCODING_SIGN2, 16, 0,
     SOX_ENCODING_UNSIGNED, 8, 0,
     0};
