@@ -282,14 +282,16 @@ static int startread(sox_format_t * ft)
 
   /* Don't believe LSF's rate for raw files */
   if ((sf->sf_info->format & SF_FORMAT_TYPEMASK) == SF_FORMAT_RAW && !ft->signal.rate) {
-    lsx_warn("'%s': sample rate not specified; trying 8kHz", ft->filename);
+    lsx_warn("`%s': sample rate not specified; trying 8kHz", ft->filename);
     rate = 8000;
   }
   else rate = sf->sf_info->samplerate;
 
-#if 0
-  if ((sf->sf_info->format & SF_FORMAT_SUBMASK) == SF_FORMAT_FLOAT)
+#ifdef HAVE_SFC_SET_SCALE_FLOAT_INT_READ
+  if ((sf->sf_info->format & SF_FORMAT_SUBMASK) == SF_FORMAT_FLOAT) {
     sf_command(sf->sf_file, SFC_SET_SCALE_FLOAT_INT_READ, NULL, SF_TRUE);
+    sf_command(sf->sf_file, SFC_SET_CLIPPING, NULL, SF_TRUE);
+  }
 #endif
 
 #if 0 /* FIXME */
@@ -363,7 +365,7 @@ static int startwrite(sox_format_t * ft)
     return SOX_EOF;
   }
 
-#if 0
+#ifdef HAVE_SFC_SET_SCALE_INT_FLOAT_WRITE
   if ((sf->sf_info->format & SF_FORMAT_SUBMASK) == SF_FORMAT_FLOAT)
     sf_command(sf->sf_file, SFC_SET_SCALE_INT_FLOAT_WRITE, NULL, SF_TRUE);
 #endif
@@ -401,7 +403,7 @@ static int seek(sox_format_t * ft, uint64_t offset)
   return SOX_SUCCESS;
 }
 
-SOX_FORMAT_HANDLER(sndfile)
+LSX_FORMAT_HANDLER(sndfile)
 {
   static char const * const names[] = {
     "sndfile", /* Special type to force use of sndfile for the following: */
